from publish import Configuration


class Setup:
    def __init__(self, configuration: Configuration, message: str):
        self.users_name = configuration.users_name
        self.message = message

    def say_hello(self):
        print(f'{self.message}, {self.users_name}')




import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    name="test-pypi-publish-philmont",
    version="1.0.0",
    description="Just a test publishing to PyPi ",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://bitbucket.org/pmontgomery3CI/test-pypi-publish",
    author="Philip Montgomery",
    author_email="pmont@cisco.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["src/publish"],
    include_package_data=True,
    install_requires=["feedparser", "html2text"]
)